@@ -13,7 +13,7 @@ from importlib.util import spec_from_loader
 from typing import Set
 
 __title__ = "anysearch"
-__version__ = "0.2"
+__version__ = "0.2.2"
 __author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
 __copyright__ = "2022 Artur Barseghyan"
 __license__ = "MIT"
@@ -268,7 +268,9 @@ _search_moved_attributes = [
     MovedAttribute("transport", "elasticsearch", "opensearchpy"),
     MovedAttribute("helpers", "elasticsearch", "opensearchpy"),
     MovedAttribute("bulk", "elasticsearch.helpers", "opensearchpy.helpers"),
-    MovedAttribute("parallel_bulk", "elasticsearch.helpers", "opensearchpy.helpers"),
+    MovedAttribute(
+        "parallel_bulk", "elasticsearch.helpers", "opensearchpy.helpers"
+    ),
     # **********************************************
     # ************* Moved attributes ***************
     # **********************************************
@@ -323,7 +325,7 @@ for _search_attr in _search_moved_attributes:
 
 try:
     del _search_attr
-except:
+except NameError:
     pass
 
 _SearchMovedItems._moved_attributes = _search_moved_attributes
@@ -459,7 +461,8 @@ _search_dsl_moved_attributes = [
     MovedAttribute("SearchAsYouType", "elasticsearch_dsl", "opensearch_dsl"),
     MovedAttribute("Short", "elasticsearch_dsl", "opensearch_dsl"),
     MovedAttribute("SparseVector", "elasticsearch_dsl", "opensearch_dsl"),
-    MovedAttribute("SparseVector", "elasticsearch_dsl", "opensearch_dsl"),
+    MovedAttribute("Text", "elasticsearch_dsl", "opensearch_dsl"),
+    MovedAttribute("TokenCount", "elasticsearch_dsl", "opensearch_dsl"),
     MovedAttribute("construct_field", "elasticsearch_dsl", "opensearch_dsl"),
     # .function
     MovedAttribute("SF", "elasticsearch_dsl", "opensearch_dsl"),
@@ -494,6 +497,26 @@ _search_dsl_moved_attributes = [
     MovedAttribute(
         "MoreLikeThis", "elasticsearch_dsl.query", "opensearch_dsl.query"
     ),
+    MovedAttribute(
+        "add_connection",
+        "elasticsearch_dsl.connections",
+        "opensearch_dsl.connections",
+    ),
+    MovedAttribute(
+        "remove_connection",
+        "elasticsearch_dsl.connections",
+        "opensearch_dsl.connections",
+    ),
+    MovedAttribute(
+        "create_connection",
+        "elasticsearch_dsl.connections",
+        "opensearch_dsl.connections",
+    ),
+    MovedAttribute(
+        "get_connection",
+        "elasticsearch_dsl.connections",
+        "opensearch_dsl.connections",
+    ),
 ]
 
 for _search_dsl_attr in _search_dsl_moved_attributes:
@@ -505,7 +528,7 @@ for _search_dsl_attr in _search_dsl_moved_attributes:
 
 try:
     del _search_dsl_attr
-except:
+except NameError:
     pass
 
 
@@ -533,23 +556,37 @@ _importer._add_module(search_dsl, "search_dsl")
 #     # **************** Moved modules ***************
 #     # **********************************************
 #     # django_elasticsearch_dsl/django_opensearch_dsl
-#     MovedModule("apps", "django_elasticsearch_dsl", "django_opensearch_dsl"),
+#     MovedModule(
+#         "apps", "django_elasticsearch_dsl", "django_opensearch_dsl"
+#     ),
 #     MovedModule(
 #         "documents", "django_elasticsearch_dsl", "django_opensearch_dsl"
 #     ),
 #     MovedModule(
 #         "exceptions", "django_elasticsearch_dsl", "django_opensearch_dsl"
 #     ),
-#     MovedModule("fields", "django_elasticsearch_dsl", "django_opensearch_dsl"),
-#     # MovedModule("indices", "django_elasticsearch_dsl", "django_opensearch_dsl"),
-#     # MovedModule("models", "django_elasticsearch_dsl", "django_opensearch_dsl"),
+#     MovedModule(
+#         "fields", "django_elasticsearch_dsl", "django_opensearch_dsl"
+#     ),
+#     # MovedModule(
+#     #     "indices", "django_elasticsearch_dsl", "django_opensearch_dsl"
+#     # ),
+#     # MovedModule(
+#     #     "models", "django_elasticsearch_dsl", "django_opensearch_dsl"
+#     # ),
 #     MovedModule(
 #         "registries", "django_elasticsearch_dsl", "django_opensearch_dsl"
 #     ),
-#     MovedModule("search", "django_elasticsearch_dsl", "django_opensearch_dsl"),
-#     MovedModule("signals", "django_elasticsearch_dsl", "django_opensearch_dsl"),
+#     MovedModule(
+#         "search", "django_elasticsearch_dsl", "django_opensearch_dsl"
+#     ),
+#     MovedModule(
+#         "signals", "django_elasticsearch_dsl", "django_opensearch_dsl"
+#     ),
 #     # Again, but now as attributes of the module.
-#     MovedAttribute("apps", "django_elasticsearch_dsl", "django_opensearch_dsl"),
+#     MovedAttribute(
+#         "apps", "django_elasticsearch_dsl", "django_opensearch_dsl"
+#     ),
 #     MovedAttribute(
 #         "documents", "django_elasticsearch_dsl", "django_opensearch_dsl"
 #     ),
@@ -559,8 +596,12 @@ _importer._add_module(search_dsl, "search_dsl")
 #     MovedAttribute(
 #         "fields", "django_elasticsearch_dsl", "django_opensearch_dsl"
 #     ),
-#     # MovedAttribute("indices", "django_elasticsearch_dsl", "django_opensearch_dsl"),
-#     # MovedAttribute("models", "django_elasticsearch_dsl", "django_opensearch_dsl"),
+#     # MovedAttribute(
+#     #     "indices", "django_elasticsearch_dsl", "django_opensearch_dsl"
+#     # ),
+#     # MovedAttribute(
+#     #     "models", "django_elasticsearch_dsl", "django_opensearch_dsl"
+#     # ),
 #     MovedAttribute(
 #         "registries", "django_elasticsearch_dsl", "django_opensearch_dsl"
 #     ),
@@ -576,7 +617,9 @@ _importer._add_module(search_dsl, "search_dsl")
 #     MovedAttribute(
 #         "Document", "django_elasticsearch_dsl", "django_opensearch_dsl"
 #     ),
-#     # MovedAttribute("Index", "django_elasticsearch_dsl", "django_opensearch_dsl"),
+#     # MovedAttribute(
+#     #     "Index", "django_elasticsearch_dsl", "django_opensearch_dsl"
+#     # ),
 #     # **********************************************
 #     # ********* Additional moved attributes ********
 #     # **********************************************
@@ -626,13 +669,15 @@ _importer._add_module(search_dsl, "search_dsl")
 #     _django_search_dsl_moved_attributes
 # )
 #
-# django_search_dsl = _DjangoSearchDSLMovedItems(__name__ + ".django_search_dsl")
+# django_search_dsl = _DjangoSearchDSLMovedItems(
+#     __name__ + ".django_search_dsl"
+# )
 # _importer._add_module(django_search_dsl, "django_search_dsl")
-
-# **************************************************
-# **************************************************
-# **************************************************
-
+#
+# # **************************************************
+# # **************************************************
+# # **************************************************
+#
 # Index = getattr(moves, "Index", None)
 #
 # if not Index:
@@ -643,12 +688,12 @@ _importer._add_module(search_dsl, "search_dsl")
 #     from django_opensearch_dsl.apps import DEDConfig
 #     from django_opensearch_dsl.registries import registry
 #
-#
 #     class Index(DSLIndex):
 #         def __init__(self, *args, **kwargs):
 #             super(Index, self).__init__(*args, **kwargs)
 #             default_index_settings = deepcopy(
-#                 DEDConfig.default_index_settings())
+#                 DEDConfig.default_index_settings()
+#             )
 #             self.settings(**default_index_settings)
 #
 #         def document(self, document):
