@@ -104,8 +104,12 @@ SEARCH_DSL_MOVED_ATTRIBUTES_TYPE_SHORTCUTS = [
 ]
 SEARCH_DSL_MOVED_ATTRIBUTES = [
     # .
-    # MovedAttribute("__version__", "elasticsearch_dsl", "opensearch_dsl"),
-    # MovedAttribute("connections", "elasticsearch_dsl", "opensearch_dsl"),  # Probably remove
+    # MovedAttribute(
+    #     "__version__", "elasticsearch_dsl", "opensearch_dsl"
+    # ),
+    # MovedAttribute(
+    #     "connections", "elasticsearch_dsl", "opensearch_dsl"
+    # ),  # Probably remove
     # .aggs
     MovedAttribute("A", "elasticsearch_dsl", "opensearch_dsl"),
     # .analysis
@@ -198,6 +202,35 @@ SEARCH_DSL_MOVED_ATTRIBUTES = [
     MovedAttribute("DslBase", "elasticsearch_dsl", "opensearch_dsl"),
     # .wrappers
     MovedAttribute("Range", "elasticsearch_dsl", "opensearch_dsl"),
+    # **********************************************
+    # ********** Additional moved attributes *******
+    # **********************************************
+    MovedAttribute(
+        "AggsProxy", "elasticsearch_dsl.search", "opensearch_dsl.search"
+    ),
+    MovedAttribute(
+        "MoreLikeThis", "elasticsearch_dsl.query", "opensearch_dsl.query"
+    ),
+    MovedAttribute(
+        "add_connection",
+        "elasticsearch_dsl.connections",
+        "opensearch_dsl.connections",
+    ),
+    MovedAttribute(
+        "remove_connection",
+        "elasticsearch_dsl.connections",
+        "opensearch_dsl.connections",
+    ),
+    MovedAttribute(
+        "create_connection",
+        "elasticsearch_dsl.connections",
+        "opensearch_dsl.connections",
+    ),
+    MovedAttribute(
+        "get_connection",
+        "elasticsearch_dsl.connections",
+        "opensearch_dsl.connections",
+    ),
 ]
 
 # DJANGO_SEARCH_DSL_MOVED_MODULES = [
@@ -212,14 +245,24 @@ SEARCH_DSL_MOVED_ATTRIBUTES = [
 #     MovedModule(
 #         "exceptions", "django_elasticsearch_dsl", "django_opensearch_dsl"
 #     ),
-#     MovedModule("fields", "django_elasticsearch_dsl", "django_opensearch_dsl"),
-#     # MovedModule("indices", "django_elasticsearch_dsl", "django_opensearch_dsl"),
-#     # MovedModule("models", "django_elasticsearch_dsl", "django_opensearch_dsl"),
+#     MovedModule(
+#         "fields", "django_elasticsearch_dsl", "django_opensearch_dsl"
+#     ),
+#     # MovedModule(
+#     #     "indices", "django_elasticsearch_dsl", "django_opensearch_dsl"
+#     # ),
+#     # MovedModule(
+#     #     "models", "django_elasticsearch_dsl", "django_opensearch_dsl"
+#     # ),
 #     MovedModule(
 #         "registries", "django_elasticsearch_dsl", "django_opensearch_dsl"
 #     ),
-#     MovedModule("search", "django_elasticsearch_dsl", "django_opensearch_dsl"),
-#     MovedModule("signals", "django_elasticsearch_dsl", "django_opensearch_dsl"),
+#     MovedModule(
+#         "search", "django_elasticsearch_dsl", "django_opensearch_dsl"
+#     ),
+#     MovedModule(
+#         "signals", "django_elasticsearch_dsl", "django_opensearch_dsl"
+#     ),
 # ]
 #
 # DJANGO_SEARCH_DSL_MOVED_ATTRIBUTES = [
@@ -229,7 +272,9 @@ SEARCH_DSL_MOVED_ATTRIBUTES = [
 #     MovedAttribute(
 #         "Document", "django_elasticsearch_dsl", "django_opensearch_dsl"
 #     ),
-#     # MovedAttribute("Index", "django_elasticsearch_dsl", "django_opensearch_dsl"),
+#     # MovedAttribute(
+#     #     "Index", "django_elasticsearch_dsl", "django_opensearch_dsl"
+#     # ),
 # ]
 
 
@@ -440,7 +485,9 @@ class SearchDSLTestCase(AnySearchBaseTestCase):
 #     # **************** django-opensearch-dsl ***********
 #     # **************************************************
 #
-#     @mock.patch.dict("os.environ", {"ANYSEARCH_PREFERRED_BACKEND": OPENSEARCH})
+#     @mock.patch.dict(
+#         "os.environ", {"ANYSEARCH_PREFERRED_BACKEND": OPENSEARCH}
+#     )
 #     @unittest.skipIf(
 #         detect_search_backend() != OPENSEARCH,
 #         "Skipped, because opensearch-dsl is not installed.",
@@ -450,7 +497,9 @@ class SearchDSLTestCase(AnySearchBaseTestCase):
 #         for name, _, package in DJANGO_SEARCH_DSL_MOVED_ATTRIBUTES:
 #             self._test_moved_attributes(name, package)
 #
-#     @mock.patch.dict("os.environ", {"ANYSEARCH_PREFERRED_BACKEND": OPENSEARCH})
+#     @mock.patch.dict(
+#         "os.environ", {"ANYSEARCH_PREFERRED_BACKEND": OPENSEARCH}
+#     )
 #     @unittest.skipIf(
 #         detect_search_backend() != OPENSEARCH,
 #         "Skipped, because opensearch-dsl is not installed.",
